@@ -1,9 +1,5 @@
 from araviq6 import get_data_path, ClickableSlider
-
-try:
-    from PySide6.QtCore import Qt, QPoint  # type: ignore[import]
-except ModuleNotFoundError:
-    from PyQt6.QtCore import Qt, QPoint  # type: ignore[import, no-redef]
+from araviq6.qt_compat import QtCore
 
 
 VID_PATH = get_data_path("hello.mp4")
@@ -14,6 +10,6 @@ def test_ClickableSlider(qtbot):
     qtbot.addWidget(slider)
     assert slider.value() == 0
 
-    pos = QPoint(10, 10)
-    qtbot.mouseClick(slider, Qt.LeftButton, pos=pos)
+    pos = QtCore.QPoint(10, 10)
+    qtbot.mouseClick(slider, QtCore.Qt.LeftButton, pos=pos)
     assert slider.value() == slider.pixelPosToRangeValue(pos)
